searchData={"items":[{"type":"module","title":"LogicGates.And","doc":"","ref":"LogicGates.And.html"},{"type":"function","title":"LogicGates.And.exec/1","doc":"Executes an AND gate on an input list. The list may contain either boolean values or anonymous functions that return\neither :ok and a boolean, or :error and a reason.\n\nAn AND gate returns true if all of the input values evaluate to true. Otherwise it returns false.\n\nIf any input value function returns an error on evaluation, this function will return an error.","ref":"LogicGates.And.html#exec/1"},{"type":"function","title":"Truth table with three input values - LogicGates.And.exec/1","doc":"iex> LogicGates.And.exec([false, false, false])\n    {:ok, :false}\n\n    iex> LogicGates.And.exec([false, false, true])\n    {:ok, :false}\n\n    iex> LogicGates.And.exec([false, true, false])\n    {:ok, :false}\n\n    iex> LogicGates.And.exec([false, true, true])\n    {:ok, :false}\n\n    iex> LogicGates.And.exec([true, false, false])\n    {:ok, :false}\n\n    iex> LogicGates.And.exec([true, false, true])\n    {:ok, :false}\n\n    iex> LogicGates.And.exec([true, true, false])\n    {:ok, :false}\n\n    iex> LogicGates.And.exec([true, true, true])\n    {:ok, :true}","ref":"LogicGates.And.html#exec/1-truth-table-with-three-input-values"},{"type":"module","title":"LogicGates.Nand","doc":"","ref":"LogicGates.Nand.html"},{"type":"function","title":"LogicGates.Nand.exec/1","doc":"Executes a NAND gate on an input list. The list may contain either boolean values or anonymous functions that return\neither :ok and a boolean, or :error and a reason.\n\nA NAND gate returns true if at least one of the input values evaluates to false. Otherwise it returns false.\n\nIf any input value function returns an error on evaluation, this function will return an error.","ref":"LogicGates.Nand.html#exec/1"},{"type":"function","title":"Truth table with three input values - LogicGates.Nand.exec/1","doc":"iex> LogicGates.Nand.exec([false, false, false])\n    {:ok, :true}\n\n    iex> LogicGates.Nand.exec([false, false, true])\n    {:ok, :true}\n\n    iex> LogicGates.Nand.exec([false, true, false])\n    {:ok, :true}\n\n    iex> LogicGates.Nand.exec([false, true, true])\n    {:ok, :true}\n\n    iex> LogicGates.Nand.exec([true, false, false])\n    {:ok, :true}\n\n    iex> LogicGates.Nand.exec([true, false, true])\n    {:ok, :true}\n\n    iex> LogicGates.Nand.exec([true, true, false])\n    {:ok, :true}\n\n    iex> LogicGates.Nand.exec([true, true, true])\n    {:ok, :false}","ref":"LogicGates.Nand.html#exec/1-truth-table-with-three-input-values"},{"type":"module","title":"LogicGates.Nor","doc":"","ref":"LogicGates.Nor.html"},{"type":"function","title":"LogicGates.Nor.exec/1","doc":"Executes a NOR gate on an input list. The list may contain either boolean values or anonymous functions that return\neither :ok and a boolean, or :error and a reason.\n\nA NOR gate returns true if all of the input values evaluate to false. Otherwise it returns false.\n\nIf any input value function returns an error on evaluation, this function will return an error.","ref":"LogicGates.Nor.html#exec/1"},{"type":"function","title":"Truth table with three input values - LogicGates.Nor.exec/1","doc":"iex> LogicGates.Nor.exec([false, false, false])\n    {:ok, :true}\n\n    iex> LogicGates.Nor.exec([false, false, true])\n    {:ok, :false}\n\n    iex> LogicGates.Nor.exec([false, true, false])\n    {:ok, :false}\n\n    iex> LogicGates.Nor.exec([false, true, true])\n    {:ok, :false}\n\n    iex> LogicGates.Nor.exec([true, false, false])\n    {:ok, :false}\n\n    iex> LogicGates.Nor.exec([true, false, true])\n    {:ok, :false}\n\n    iex> LogicGates.Nor.exec([true, true, false])\n    {:ok, :false}\n\n    iex> LogicGates.Nor.exec([true, true, true])\n    {:ok, :false}","ref":"LogicGates.Nor.html#exec/1-truth-table-with-three-input-values"},{"type":"module","title":"LogicGates.Not","doc":"","ref":"LogicGates.Not.html"},{"type":"function","title":"LogicGates.Not.exec/1","doc":"Executes an NOT gate on an input which is either a boolean or an anonymous function that returns\neither :ok and a boolean, or :error and a reason. The input can also be a list with exactly one element of the type\ndescribed above.\n\nAn NOT gate returns true if the input value evaluates to false, and vice versa.\n\nIf any input value function returns an error on evaluation, this function will return an error.","ref":"LogicGates.Not.html#exec/1"},{"type":"function","title":"Truth table - LogicGates.Not.exec/1","doc":"iex> LogicGates.Not.exec(false)\n    {:ok, :true}\n\n    iex> LogicGates.Not.exec(true)\n    {:ok, :false}","ref":"LogicGates.Not.html#exec/1-truth-table"},{"type":"module","title":"LogicGates.Or","doc":"","ref":"LogicGates.Or.html"},{"type":"function","title":"LogicGates.Or.exec/1","doc":"Executes an OR gate on an input list. The list may contain either boolean values or anonymous functions that return\neither :ok and a boolean, or :error and a reason.\n\nAn OR gate returns true if at least one of the input values evaluates to true. Otherwise it returns false.\n\nIf any input value function returns an error on evaluation, this function will return an error.","ref":"LogicGates.Or.html#exec/1"},{"type":"function","title":"Truth table with three input values - LogicGates.Or.exec/1","doc":"iex> LogicGates.Or.exec([false, false, false])\n    {:ok, :false}\n\n    iex> LogicGates.Or.exec([false, false, true])\n    {:ok, :true}\n\n    iex> LogicGates.Or.exec([false, true, false])\n    {:ok, :true}\n\n    iex> LogicGates.Or.exec([false, true, true])\n    {:ok, :true}\n\n    iex> LogicGates.Or.exec([true, false, false])\n    {:ok, :true}\n\n    iex> LogicGates.Or.exec([true, false, true])\n    {:ok, :true}\n\n    iex> LogicGates.Or.exec([true, true, false])\n    {:ok, :true}\n\n    iex> LogicGates.Or.exec([true, true, true])\n    {:ok, :true}","ref":"LogicGates.Or.html#exec/1-truth-table-with-three-input-values"},{"type":"module","title":"LogicGates.Xor","doc":"","ref":"LogicGates.Xor.html"},{"type":"function","title":"LogicGates.Xor.exec/1","doc":"Executes an XOR gate on an input list. The list may contain either boolean values or anonymous functions that return\neither :ok and a boolean, or :error and a reason.\n\nAn XOR gate requires at least 2 input values.\n\nAn XOR gate returns true if one input value evaluates to true and the other input value evaluates to false. If the number of input values for the XOR gate is greater than 2, it behaves as a cascade of 2-input gates and performs an odd-parity function. In effect that means that the output of the XOR gate is true if the number of true input values is odd, otherwise the output is false. This can lead to some confusion in cases such as this:\n\n    iex> LogicGates.Xor.exec([true, true, true])\n    {:ok, :true}\n\nFor that reason it's recommended to just stick to two input values in most cases.\n\nIf any input value function returns an error on evaluation, this function will return an error.","ref":"LogicGates.Xor.html#exec/1"},{"type":"function","title":"Truth table with two input values - LogicGates.Xor.exec/1","doc":"iex> LogicGates.Xor.exec([false, false])\n    {:ok, :false}\n\n    iex> LogicGates.Xor.exec([false, true])\n    {:ok, :true}\n\n    iex> LogicGates.Xor.exec([true, false])\n    {:ok, :true}\n\n    iex> LogicGates.Xor.exec([true, true])\n    {:ok, :false}","ref":"LogicGates.Xor.html#exec/1-truth-table-with-two-input-values"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}